LinePositions

Type Alias LinePositions 

pub(crate) type LinePositions = SmallVec<[u32; 4]>;
The one-indexed line positions of a single grid line name. Inline capacity of 4 keeps the type the same size as Vec<u32> (24 bytes) while avoiding a heap allocation for names mapping to at most 4 lines (the common case)

Aliased Type

pub(crate) struct LinePositions { /* private fields */ }